==> groupoffice-6.1.80.txz: usr/local/www/groupoffice6/modules/users/language/en.php <==
<?php


$l["cmdCheckColumnRead"]= 'Use';
$l["cmdCheckColumnWrite"]= 'Manage';
$l["cmdHeaderColumnName"]= 'Module name';
$l["cmdHeaderGridUserHasAccess"]= 'User has access to';
$l["userIsMemberOf"]= 'User is member of';
$l["userVisibleTo"]= 'User is visible to';
$l["cmdPanelPersonal"]= 'Personal';
$l["cmdPanelPassword"]= 'Password';
$l["cmdPanelCompany"]= 'Company';
$l["cmdPanelPermissions"]= 'Permissions';
$l["cmdPanelLogin"]= 'Login';
$l["cmdPanelLookFeel"]= 'Look & Feel';
$l["cmdPanelSettings"]= 'Settings';
$l["cmdPanelEnabledMail"]= 'Email for new enabled users';
$l["cmdPanelDisabledMail"]= 'Email for new disabled users';
$l["cmdFieldSetPersonal"]= 'Personal';	;
$l["cmdUserWindowTitle"]= 'Edit User';
$l["cmdNotificationWindowTitle"]= 'Edit user invitation email';
$l["cmdMaskSaving"]= 'Saving';
$l["cmdFormLabelSubject"]= 'Subject';
$l["cmdFormLabelUsername"]= 'Username';
$l["cmdFormLabelName"]= 'Name';
$l["cmdFormLabelPassword"]= 'Password';
$l["cmdFormLabelConfirm"]= 'Confirm';
$l["cmdBoxLabelEnabled"]= 'Enabled';
$l["cmdFormLabelHomepage"]= 'Homepage';
$l["cmdFormLabelRegistrationTime"]= 'Registration time';
$l["cmdFormLabelLastLogin"]= 'Last Login';
$l["cmdFormLabelTotalLogins"]= 'Total Logins';
$l["numberOfLogins"]= 'Number of logins';
$l["cmdFormLabelTheme"]= 'Theme';
$l["cmdFormLabelStartModule"]= 'Start in module';
$l["cmdFormLabelMaximunRows"]= 'Maximum number of rows in lists';
$l["cmdFormLabelSortNamesBy"]= 'Sort names by';
$l["cmdFormLabelLanguage"]= 'Language';
$l["cmdFormLabelTimezone"]= 'Timezone';
$l["cmdFormLabelAdjustDaylight"]= 'Automatically adjust time to Daylight Savings Time';
$l["cmdFormLabelDateFormat"]= 'Date Format';
$l["cmdFormLabelDateSeperator"]= 'Date Seperator';
$l["timeFormat"]= 'Time Format';
$l["cmdFormLabelFirstWeekday"]= 'First weekday';
$l["cmdFormLabelThousandSeperator"]= 'Thousand Seperator';
$l["cmdFormLabelDecimalSeperator"]= 'Decimal Seperator';
$l["cmdFormLabelCurrency"]= 'Currency';
$l["account"]= 'Account';
$l["companyProfile"]= 'Company profile';
$l["loginInfo"]= 'Login information';
$l["changePassword"]= 'Change password';
$l["currentPassword"]= 'Current password';
$l["newPassword"]= 'New password';
$l["confirmPassword"]= 'Confirm password';
$l["moduleAccess"]= 'Module access';
$l["groupMembership"]= 'Group membership';
$l["personalProfile"]= 'Personal profile';
$l["settings"]= 'Personal settings';
$l["dmy"]= 'Day-Month-Year';
$l["mdy"]= 'Month-Day-Year';
$l["jmd"]= 'Year-Month-Day';
$l["fullhourformat"]= '24 hour format';
$l["halfhourformat"]= '12 hour format';
$l["sunday"]= 'Sunday';
$l["monday"]= 'Monday';
$l["regionalSettings"]= 'Regional settings';
$l["userSettings"]= 'User settings';
$l["profile"]='Profile';
$l["maxUsersReached"]='The maximum number of users has been reached. Contact your hosting provider to extend your maximum number of users.';
$l["group"]='Group';
$l["muteSound"]='Mute all sounds';
$l["mailReminders"]='Mail reminders';
$l["downloadSampleCSV"]='Download sample CSV';
$l["importText"]='You can import users using a CSV file. To know how the CSV file should be formatted, download the sample file.<br />The first line must contain the column names. The following fields are required for each user:<br /><br />username, password, first_name, last_name, email';
$l["useModule"]= 'Use';
$l["manageModule"]= 'Manage';
$l["numberFormat"]='Number format';
$l["importExport"]='Import / Export';
$l["listSeparator"]='List separator';
$l["textSeparator"]='Text separator';
$l["deleteWarning"]='WARNING!!! All of the user data including addressbooks, projects, calendars etc. will be deleted!';
$l["lastName"]= 'Last name';
$l["firstName"]= 'First name';
$l["sendInvitation"]='Send invitation';
$l["contactInfo"]='Contact info';
$l["popupNotification"]='Show a popup window when a reminder becomes active or an e-mail arrives';
$l["muteNewMailSound"]='Mute new mail sounds';
$l["muteReminderSound"]='Mute reminder sounds';
$l["showSmilies"]='Show smilies';
$l["autoPunctuation"]='Capital after punctuation';
$l['name'] = 'Users';
$l['description'] = 'Admin module. Managing system users.';
$l['deletePrimaryAdmin'] = 'You can\'t delete the primary administrator';
$l['deleteYourself'] = 'You can\'t delete yourself';
$l['error_username']='You have invalid characters in the username';
$l['error_username_exists']='Sorry, that username already exists';
$l['error_email_exists']='Sorry, that e-mail address is already registered here.';
$l['error_match_pass']='The passwords didn\'t match';
$l['error_email']='You entered an invalid e-mail address';
$l['error_user']='User could not be created';
$l['imported']='Imported %s users';
$l['failed']='Failed';
$l['incorrectFormat']='File was not in correct CSV format';
$l['register_email_subject']='Your {product_name} account details';
$l['register_email_body']='A {product_name} account has been created for you at {url}
Your login details are:
Username: {username};
Password: {password}';
$l['max_users_reached']='The maximum number of users has been reached for this system.';

$l['dashdmy']='Day-Month-Year';
$l['slashmdy']='Month/Day/Year';
$l['dotdmy']='Day.Month.Year';
$l['slashdmy']='Day/Month/Year';
$l['slashymd']='Year-Month-Day';
$l['dotymd']='Year.Month.Day';

$l['generatePassword']='Generate password';
$l['generatedPasswordIs']='The generated password is';

$l['openContact']='Open contact';
$l['showProUsers']='Show pro users';

$l['updateExistingOnImport']='Update existing users by username';
$l['resetState']="Reset windows and grids";
$l['resetStateConfirm']='Are you sure you want to reset all grid columns, windows, panel sizes etc. to the factory defaults?';

$l['registrationEmail']='Registration Email';
$l['enabledSettingtabs']='Enabled Setting tabs';


$l['explanation_cf_settingspanels']='To show the custom field tabs in the settings panel you need to be sure that the user has at least "Read" access to the custom fields module.';
$l['addresslist_panel'] = 'Address list panel';
$l['show_addresslists_panel'] = 'Show the addresslist panel';
$l['enabled_cf_tabs'] = 'Enabled custom field tabs';
$l['addresslist_panel'] = 'Address list panel';

$l['cmdFormLabelHolidaySet'] = 'Bank holidays';
$l['diskSpace'] = 'Disk Space';
$l['diskQuota'] = 'Disk Quota';
$l['spaceUsed'] = 'Space used';

$l['noReminders'] = 'Do not create reminders for me';
$l['transferData'] = 'Transfer data';

$l["id"]= 'ID';

==> groupoffice-6.2.19.txz: usr/local/www/groupoffice6/modules/users/language/en.php <==
<?php


$l["cmdCheckColumnRead"]= 'Use';
$l["cmdCheckColumnWrite"]= 'Manage';
$l["cmdHeaderColumnName"]= 'Module name';
$l["cmdHeaderGridUserHasAccess"]= 'User has access to';
$l["userIsMemberOf"]= 'User is member of';
$l["userVisibleTo"]= 'User is visible to';
$l["cmdPanelPersonal"]= 'Personal';
$l["cmdPanelPassword"]= 'Password';
$l["cmdPanelCompany"]= 'Company';
$l["cmdPanelPermissions"]= 'Permissions';
$l["cmdPanelLogin"]= 'Login';
$l["cmdPanelLookFeel"]= 'Look & Feel';
$l["cmdPanelSettings"]= 'Settings';
$l["cmdPanelEnabledMail"]= 'Email for new enabled users';
$l["cmdPanelDisabledMail"]= 'Email for new disabled users';
$l["cmdFieldSetPersonal"]= 'Personal';	;
$l["cmdUserWindowTitle"]= 'Edit User';
$l["cmdNotificationWindowTitle"]= 'Edit user invitation email';
$l["cmdMaskSaving"]= 'Saving';
$l["cmdFormLabelSubject"]= 'Subject';
$l["cmdFormLabelUsername"]= 'Username';
$l["cmdFormLabelName"]= 'Name';
$l["cmdFormLabelPassword"]= 'Password';
$l["cmdFormLabelConfirm"]= 'Confirm';
$l["cmdBoxLabelEnabled"]= 'Enabled';
$l["cmdFormLabelHomepage"]= 'Homepage';
$l["cmdFormLabelRegistrationTime"]= 'Registration time';
$l["cmdFormLabelLastLogin"]= 'Last Login';
$l["cmdFormLabelTotalLogins"]= 'Total Logins';
$l["numberOfLogins"]= 'Number of logins';
$l["cmdFormLabelTheme"]= 'Theme';
$l["cmdFormLabelStartModule"]= 'Start in module';
$l["cmdFormLabelMaximunRows"]= 'Maximum number of rows in lists';
$l["cmdFormLabelSortNamesBy"]= 'Sort names by';
$l["cmdFormLabelLanguage"]= 'Language';
$l["cmdFormLabelTimezone"]= 'Timezone';
$l["cmdFormLabelAdjustDaylight"]= 'Automatically adjust time to Daylight Savings Time';
$l["cmdFormLabelDateFormat"]= 'Date Format';
$l["cmdFormLabelDateSeperator"]= 'Date Seperator';
$l["timeFormat"]= 'Time Format';
$l["cmdFormLabelFirstWeekday"]= 'First weekday';
$l["cmdFormLabelThousandSeperator"]= 'Thousand Seperator';
$l["cmdFormLabelDecimalSeperator"]= 'Decimal Seperator';
$l["cmdFormLabelCurrency"]= 'Currency';
$l["account"]= 'Account';
$l["companyProfile"]= 'Company profile';
$l["loginInfo"]= 'Login information';
$l["changePassword"]= 'Change password';
$l["currentPassword"]= 'Current password';
$l["newPassword"]= 'New password';
$l["confirmPassword"]= 'Confirm password';
$l["moduleAccess"]= 'Module access';
$l["groupMembership"]= 'Group membership';
$l["personalProfile"]= 'Personal profile';
$l["settings"]= 'Personal settings';
$l["dmy"]= 'Day-Month-Year';
$l["mdy"]= 'Month-Day-Year';
$l["jmd"]= 'Year-Month-Day';
$l["fullhourformat"]= '24 hour format';
$l["halfhourformat"]= '12 hour format';
$l["sunday"]= 'Sunday';
$l["monday"]= 'Monday';
$l["regionalSettings"]= 'Regional settings';
$l["userSettings"]= 'User settings';
$l["profile"]='Profile';
$l["maxUsersReached"]='The maximum number of users has been reached. Contact your hosting provider to extend your maximum number of users.';
$l["group"]='Group';
$l["muteSound"]='Mute all sounds';
$l["mailReminders"]='Mail reminders';
$l["downloadSampleCSV"]='Download sample CSV';
$l["importText"]='You can import users using a CSV file. To know how the CSV file should be formatted, download the sample file.<br />The first line must contain the column names. The following fields are required for each user:<br /><br />username, password, first_name, last_name, email';
$l["useModule"]= 'Use';
$l["manageModule"]= 'Manage';
$l["numberFormat"]='Number format';
$l["importExport"]='Import / Export';
$l["listSeparator"]='List separator';
$l["textSeparator"]='Text separator';
$l["deleteWarning"]='WARNING!!! All of the user data including addressbooks, projects, calendars etc. will be deleted!';
$l["lastName"]= 'Last name';
$l["firstName"]= 'First name';
$l["sendInvitation"]='Send invitation';
$l["contactInfo"]='Contact info';
$l["popupNotification"] = 'Show a popup window when a reminder becomes active or an e-mail arrives';
$l["popupReminderNotification"] = 'Show a popup window when a reminder becomes active';
$l["popupEmailNotification"] = 'Show a popup window when an e-mail arrives';
$l["muteNewMailSound"]='Mute new mail sounds';
$l["muteReminderSound"]='Mute reminder sounds';
$l["showSmilies"]='Show smilies';
$l["autoPunctuation"]='Capital after punctuation';
$l['name'] = 'Users';
$l['description'] = 'Admin module. Managing system users.';
$l['deletePrimaryAdmin'] = 'You can\'t delete the primary administrator';
$l['deleteYourself'] = 'You can\'t delete yourself';
$l['error_username']='You have invalid characters in the username';
$l['error_username_exists']='Sorry, that username already exists';
$l['error_email_exists']='Sorry, that e-mail address is already registered here.';
$l['error_match_pass']='The passwords didn\'t match';
$l['error_email']='You entered an invalid e-mail address';
$l['error_user']='User could not be created';
$l['imported']='Imported %s users';
$l['failed']='Failed';
$l['incorrectFormat']='File was not in correct CSV format';
$l['register_email_subject']='Your {product_name} account details';
$l['register_email_body']='A {product_name} account has been created for you at {url}
Your login details are:
Username: {username};
Password: {password}';
$l['max_users_reached']='The maximum number of users has been reached for this system.';

$l['dashdmy']='Day-Month-Year';
$l['slashmdy']='Month/Day/Year';
$l['dotdmy']='Day.Month.Year';
$l['slashdmy']='Day/Month/Year';
$l['slashymd']='Year-Month-Day';
$l['dotymd']='Year.Month.Day';

$l['generatePassword']='Generate password';
$l['generatedPasswordIs']='The generated password is';

$l['openContact']='Open contact';
$l['showProUsers']='Show pro users';

$l['updateExistingOnImport']='Update existing users by username';
$l['resetState']="Reset windows and grids";
$l['resetStateConfirm']='Are you sure you want to reset all grid columns, windows, panel sizes etc. to the factory defaults?';

$l['registrationEmail']='Registration Email';
$l['enabledSettingtabs']='Enabled Setting tabs';


$l['explanation_cf_settingspanels']='To show the custom field tabs in the settings panel you need to be sure that the user has at least "Read" access to the custom fields module.';
$l['addresslist_panel'] = 'Address list panel';
$l['show_addresslists_panel'] = 'Show the addresslist panel';
$l['enabled_cf_tabs'] = 'Enabled custom field tabs';
$l['addresslist_panel'] = 'Address list panel';

$l['cmdFormLabelHolidaySet'] = 'Bank holidays';
$l['diskSpace'] = 'Disk Space';
$l['diskQuota'] = 'Disk Quota';
$l['spaceUsed'] = 'Space used';

$l['noReminders'] = 'Do not create reminders for me';
$l['transferData'] = 'Transfer data';
$l['desktopNotificationsActive'] = 'Desktop notifications active';

$l["id"]= 'ID';


$l["alternativeEmail"]= 'Alternative email';
$l["alternativeEmailText"]= 'This email address is used as an alternative to send a forgotten password request to. Please use an email address that you can access from outside Group-Office.';
